package ru.myitschool.work.ui.main

import android.os.Bundle
import android.view.View
import android.widget.Toast
import androidx.fragment.app.Fragment
import androidx.fragment.app.setFragmentResultListener
import androidx.lifecycle.lifecycleScope
import androidx.navigation.fragment.findNavController
import kotlinx.coroutines.launch
import ru.myitschool.work.R
import ru.myitschool.work.api.ApiService
import ru.myitschool.work.api.EmployeeData
import ru.myitschool.work.core.Constants
import ru.myitschool.work.databinding.FragmentMainBinding
import ru.myitschool.work.SessionManager
import retrofit2.Retrofit
import retrofit2.converter.gson.GsonConverterFactory
import ru.myitschool.work.ui.qr.scan.QrScanDestination

class MainFragment : Fragment(R.layout.fragment_main) {
    private var _binding: FragmentMainBinding? = null
    private val binding get() = _binding!!

    private lateinit var apiService: ApiService

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        apiService = Retrofit.Builder()
            .baseUrl(Constants.SERVER_ADDRESS)
            .addConverterFactory(GsonConverterFactory.create())
            .build()
            .create(ApiService::class.java)
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        _binding = FragmentMainBinding.bind(view)

        setupUI()
        fetchUserInfo()

        // Проверяем, есть ли результат QR
        checkQrResult()
    }

    private fun checkQrResult() {
        // Слушаем результат QR сканирования
        setFragmentResultListener(QrScanDestination.REQUEST_KEY) { _, bundle ->
            val qrData = QrScanDestination.getDataIfExist(bundle)
            if (qrData != null) {
                // Если данные QR есть, переходим на экран с результатом
                val resultBundle = QrScanDestination.packToBundle(qrData)
                findNavController().navigate(R.id.qrResultFragment, resultBundle)
            } else {
                Toast.makeText(requireContext(), "QR данные не найдены", Toast.LENGTH_SHORT).show()
            }
        }
    }

    private fun setupUI() {
        binding.refresh.setOnClickListener {
            fetchUserInfo()
        }

        binding.scanQrCode?.setOnClickListener {
            // Переход к экрану сканирования QR-кода
            findNavController().navigate(R.id.qrScanFragment) // Убедитесь, что у вас есть правильный ID для навигации
        }
    }

    private fun fetchUserInfo() {
        lifecycleScope.launch {
            val login = SessionManager.userLogin ?: return@launch
            val authHeader = SessionManager.getAuthHeader()
            val response = apiService.getUserInfo(login, authHeader)
//.
            if (response.isSuccessful) {
                val employeeData = response.body()
                employeeData?.let {
                    binding.fullname.text = it.name
                    binding.position.text = it.position
                    binding.lastEntry.text = it.lastVisit
                    binding.photo.visibility = View.VISIBLE
                    binding.fullname.visibility = View.VISIBLE
                    binding.position.visibility = View.VISIBLE
                    binding.lastEntry.visibility = View.VISIBLE

                    // Показываем кнопку "Сканировать QR-код" после успешного получения данных
                    binding.scanQrCode?.visibility = View.VISIBLE
                }
            } else {
                binding.error.text = "Ошибка получения данных"
                binding.error.visibility = View.VISIBLE
            }
        }
    }

    override fun onDestroyView() {
        _binding = null
        super.onDestroyView()
    }
}