package ru.myitschool.work.ui.qr.result

import ru.myitschool.work.ui.qr.scan.QrScanDestination
import androidx.navigation.fragment.findNavController
import ru.myitschool.work.SessionManager
import ru.myitschool.work.api.OpenDoorRequest
import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.lifecycle.lifecycleScope
import kotlinx.coroutines.launch
import retrofit2.Retrofit
import retrofit2.converter.gson.GsonConverterFactory
import ru.myitschool.work.R
import ru.myitschool.work.api.ApiService
import ru.myitschool.work.core.Constants
import ru.myitschool.work.databinding.FragmentQrScanResultBinding

class QrResult : Fragment(R.layout.fragment_qr_scan_result) {
    private var _binding: FragmentQrScanResultBinding? = null
    private val binding get() = _binding!!

    private lateinit var apiService: ApiService

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        _binding = FragmentQrScanResultBinding.inflate(inflater, container, false)
        apiService = Retrofit.Builder()
            .baseUrl(Constants.SERVER_ADDRESS)
            .addConverterFactory(GsonConverterFactory.create())
            .build()
            .create(ApiService::class.java)

        return binding.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        // Получаем данные из аргументов
        val qrData = QrScanDestination.getDataIfExist(requireArguments())
        Log.d("QrResult", "QR Data: $qrData") // Логируем полученные данные

        if (qrData != null) {
            binding.result.text = "Результат сканирования: $qrData" // Отображаем результат сканирования
            sendRequestToServer(qrData)
        } else {
            binding.result.text = "Вход был отменён/Operation was cancelled"
        }

        binding.close.setOnClickListener {
            findNavController().popBackStack()
        }
    }

    private fun sendRequestToServer(qrData: String) {
        lifecycleScope.launch {
            try {
                val login = SessionManager.userLogin
                if (login != null) {
                    val openDoorRequest = OpenDoorRequest(login, qrData.toLong()) // Преобразуем qrData в Long
                    val response = apiService.openDoor(openDoorRequest)
                    if (response.isSuccessful) {
                        binding.result.text = "Успешно/Success"
                    } else {
                        binding.result.text = "Что-то пошло не так/Something went wrong: ${response.message()}"
                    }
                } else {
                    binding.result.text = "Пользователь не авторизован/Unauthorized user"
                }
            } catch (e: Exception) {
                binding.result.text = "Что-то пошло не так/Something went wrong: ${e.message}"
                Log.e("QrResult", "Error sending request to server", e)
            }
        }
    }

    override fun onDestroyView() {
        _binding = null
        super.onDestroyView()
    }
}